Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type OAuthAccessTokenExpansion
- type OAuthAccessTokenInterface
- type OAuthAccessTokensGetter
- type OAuthAuthorizeTokenExpansion
- type OAuthAuthorizeTokenInterface
- type OAuthAuthorizeTokensGetter
- type OAuthClientAuthorizationExpansion
- type OAuthClientAuthorizationInterface
- type OAuthClientAuthorizationsGetter
- type OAuthClientExpansion
- type OAuthClientInterface
- type OAuthClientsGetter
- type OauthClient
- func (c *OauthClient) OAuthAccessTokens() OAuthAccessTokenInterface
- func (c *OauthClient) OAuthAuthorizeTokens() OAuthAuthorizeTokenInterface
- func (c *OauthClient) OAuthClientAuthorizations() OAuthClientAuthorizationInterface
- func (c *OauthClient) OAuthClients() OAuthClientInterface
- func (c *OauthClient) RESTClient() rest.Interface
- type OauthInterface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OAuthAccessTokenExpansion ¶
type OAuthAccessTokenExpansion interface{}
type OAuthAccessTokenInterface ¶
type OAuthAccessTokenInterface interface {
Create(*oauth.OAuthAccessToken) (*oauth.OAuthAccessToken, error)
Update(*oauth.OAuthAccessToken) (*oauth.OAuthAccessToken, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*oauth.OAuthAccessToken, error)
List(opts v1.ListOptions) (*oauth.OAuthAccessTokenList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *oauth.OAuthAccessToken, err error)
OAuthAccessTokenExpansion
}
OAuthAccessTokenInterface has methods to work with OAuthAccessToken resources.
type OAuthAccessTokensGetter ¶
type OAuthAccessTokensGetter interface {
OAuthAccessTokens() OAuthAccessTokenInterface
}
OAuthAccessTokensGetter has a method to return a OAuthAccessTokenInterface. A group's client should implement this interface.
type OAuthAuthorizeTokenExpansion ¶
type OAuthAuthorizeTokenExpansion interface{}
type OAuthAuthorizeTokenInterface ¶
type OAuthAuthorizeTokenInterface interface {
Create(*oauth.OAuthAuthorizeToken) (*oauth.OAuthAuthorizeToken, error)
Update(*oauth.OAuthAuthorizeToken) (*oauth.OAuthAuthorizeToken, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*oauth.OAuthAuthorizeToken, error)
List(opts v1.ListOptions) (*oauth.OAuthAuthorizeTokenList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *oauth.OAuthAuthorizeToken, err error)
OAuthAuthorizeTokenExpansion
}
OAuthAuthorizeTokenInterface has methods to work with OAuthAuthorizeToken resources.
type OAuthAuthorizeTokensGetter ¶
type OAuthAuthorizeTokensGetter interface {
OAuthAuthorizeTokens() OAuthAuthorizeTokenInterface
}
OAuthAuthorizeTokensGetter has a method to return a OAuthAuthorizeTokenInterface. A group's client should implement this interface.
type OAuthClientAuthorizationExpansion ¶
type OAuthClientAuthorizationExpansion interface{}
type OAuthClientAuthorizationInterface ¶
type OAuthClientAuthorizationInterface interface {
Create(*oauth.OAuthClientAuthorization) (*oauth.OAuthClientAuthorization, error)
Update(*oauth.OAuthClientAuthorization) (*oauth.OAuthClientAuthorization, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*oauth.OAuthClientAuthorization, error)
List(opts v1.ListOptions) (*oauth.OAuthClientAuthorizationList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *oauth.OAuthClientAuthorization, err error)
OAuthClientAuthorizationExpansion
}
OAuthClientAuthorizationInterface has methods to work with OAuthClientAuthorization resources.
type OAuthClientAuthorizationsGetter ¶
type OAuthClientAuthorizationsGetter interface {
OAuthClientAuthorizations() OAuthClientAuthorizationInterface
}
OAuthClientAuthorizationsGetter has a method to return a OAuthClientAuthorizationInterface. A group's client should implement this interface.
type OAuthClientExpansion ¶
type OAuthClientExpansion interface{}
type OAuthClientInterface ¶
type OAuthClientInterface interface {
Create(*oauth.OAuthClient) (*oauth.OAuthClient, error)
Update(*oauth.OAuthClient) (*oauth.OAuthClient, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*oauth.OAuthClient, error)
List(opts v1.ListOptions) (*oauth.OAuthClientList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *oauth.OAuthClient, err error)
OAuthClientExpansion
}
OAuthClientInterface has methods to work with OAuthClient resources.
type OAuthClientsGetter ¶
type OAuthClientsGetter interface {
OAuthClients() OAuthClientInterface
}
OAuthClientsGetter has a method to return a OAuthClientInterface. A group's client should implement this interface.
type OauthClient ¶
type OauthClient struct {
// contains filtered or unexported fields
}
OauthClient is used to interact with features provided by the oauth.openshift.io group.
func New ¶
func New(c rest.Interface) *OauthClient
New creates a new OauthClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*OauthClient, error)
NewForConfig creates a new OauthClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *OauthClient
NewForConfigOrDie creates a new OauthClient for the given config and panics if there is an error in the config.
func (*OauthClient) OAuthAccessTokens ¶
func (c *OauthClient) OAuthAccessTokens() OAuthAccessTokenInterface
func (*OauthClient) OAuthAuthorizeTokens ¶
func (c *OauthClient) OAuthAuthorizeTokens() OAuthAuthorizeTokenInterface
func (*OauthClient) OAuthClientAuthorizations ¶
func (c *OauthClient) OAuthClientAuthorizations() OAuthClientAuthorizationInterface
func (*OauthClient) OAuthClients ¶
func (c *OauthClient) OAuthClients() OAuthClientInterface
func (*OauthClient) RESTClient ¶
func (c *OauthClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type OauthInterface ¶
type OauthInterface interface {
RESTClient() rest.Interface
OAuthAccessTokensGetter
OAuthAuthorizeTokensGetter
OAuthClientsGetter
OAuthClientAuthorizationsGetter
}
Source Files
¶
- doc.go
- generated_expansion.go
- oauth_client.go
- oauthaccesstoken.go
- oauthauthorizetoken.go
- oauthclient.go
- oauthclientauthorization.go